==> owncloud-news_5.3.8%2Bdfsg.orig.tar.gz: news-5.3.8/l10n/sr.php <==
<?php
$TRANSLATIONS = array(
"Feed contains invalid XML" => "Довод садржи неисправан ИксМЛ",
"Could not find a feed" => "Не могу да нађем довод",
"Detected feed format is not supported" => "Откривени формат довода није подржан",
"SSL Certificate is invalid" => "ССЛ сертификат није исправан",
"Website not found" => "Веб сајт није пронађен",
"More redirects than allowed, aborting" => "Превише преусмеравања. Прекидам",
"Bigger than maximum allowed size" => "Веће него што је дозвољено",
"Request timed out" => "Време истека захтева",
"Request failed, network connection unavailable!" => "Неуспео захтев. Мрежа није доступна!",
"Request unauthorized. Are you logged in?" => "Неауторизован захтев. Јесте ли пријављени?",
"Request forbidden. Are you an admin?" => "Забрањен захтев. Ви сте администратор?",
"Token expired or app not enabled! Reload the page!" => "Дигитални кључ је истекао или апликација није омогућена! Учитајте поново страницу!",
"Internal server error! Please check your " => "Интерна грешка сервера! Молимо вас да проверите ваше",
"Request failed, ownCloud is in currently " => "Захтев није успео. оунКлауд је тренутно",
"Can not add feed: Exists already" => "Не могу да додам довод. Већ постоји",
"Articles without feed" => "Чланци без довода",
"Can not add folder: Exists already" => "Не могу да додам фасциклу. Већ постоји",
"Use ownCloud cron for updates" => "Користите оунКлаудов cron за ажурирања",
"Disable this if you run a custom updater such as the Python updater included in the app" => "Онемогућите ово ако користите прилагођени програма за ажурирање као што су Python-ов програм за ажурирање у оквиру апликације",
"Purge interval" => "Интервал чишћења",
"Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" => "Минимални број секунди пошто се обрисане емисије и фасцикле уклоне из базе; вредности испод 60 секунди се игноришу",
"Maximum read count per feed" => "Максимални број читања по емисији",
"Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" => "Дефинише максимални број чланака који се могу прочитати по eмисији који неће бити избрисани од стране диспечера; ако се стари чланци поново појављују након што их прочитате, повећајте ову вредност; негативне вредности попут -1 искључују ову функцију у потпуности.",
"Maximum redirects" => "Највише преусмеравања",
"How many redirects the feed fetcher should follow" => "Колико ће се преусмеравања следити",
"Maximum feed page size" => "Највећа страница довода",
"Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" => "Највећа величина довода у бајтовима. Ако је страница довода већа, ажурирање ће бити прекинуто.",
"Feed fetcher timeout" => "Време чекања довлачења",
"Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" => "Време у секундама које ће се чекати да се довод учита. Ако траје дуже, ажурирање ће се прекинути",
"Explore Service URL" => "Истражите сервисну адресу",
"If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" => "Ако је дато, ова сервисна адреса ће бити упитана за приказивање у секцији за истраживање емисије. За повратак за коришћење уграђеног сервис за истраживање, оставите ово празна",
"Saved" => "Сачувано",
"Download" => "Преузми",
"Close" => "Затвори",
"Ajax cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." => "Откривен је режим Ајакс крона! Ваше емисије неће бити ажуриране коректно. Препоручено је да користите системски крон или прилагођени програм за ажурирање.",
"How to set up the operating system cron" => "Како подестити крон оперативног система",
"How to set up a custom updater (faster and no possible deadlock) " => "Како подесити прилагођени систем за ажурирање (брже и без застоја)",
"Subscribe" => "Претплати ме",
"Refresh" => "Освежи",
"No articles available" => "Нема доступних чланака",
"No unread articles available" => "Нема непрочитаних чланака",
"Open website" => "Отвори веб сајт",
"Star article" => "Озвездај чланак",
"Unstar article" => "Скини звездицу",
"Keep article unread" => "Остави чланак непрочитаним",
"Remove keep article unread" => "Уклони да остане непрочитан",
"by" => "од",
"from" => "од",
"Play audio" => "Пустио аудио",
"Download video" => "Преузми видео",
"Download audio" => "Преузми аудио",
"Keyboard shortcut" => "Пречица тастатуре",
"Description" => "Опис",
"right" => "десно",
"Jump to next article" => "Пређи на следећи чланак",
"left" => "лево",
"Jump to previous article" => "Пређи на претходни чланак",
"Toggle star article" => "Мења озвезданост чланка",
"Star article and jump to next one" => "Озвездај чланак и иди на следећи",
"Toggle keep current article unread" => "Мења „остави тренутни чланак непрочитаним“",
"Open article in new tab" => "Отвори чланак у новом језичку",
"Toggle expand article in compact view" => "Мења „рашири чланак у компактном приказу“",
"Load next feed" => "Учитај следећи довод",
"Load previous feed" => "Учитај претходни довод",
"Load next folder" => "Учитај следећу фасциклу",
"Load previous folder" => "Учитај претходну фасциклу",
"Scroll to active navigation entry" => "Отклизај до активног уноса",
"Focus search field" => "Фокусирај на поље за претрагу",
"Mark current article's feed/folder read" => "Означи доводе/фасцикле тренутног чланка прочитаним",
"Web address" => "Веб адреса",
"Feed exists already!" => "Довод већ постоји!",
"Folder" => "фасцикла",
"No folder" => "Нема фасцикле",
"New folder" => "Нова фасцикла",
"Folder name" => "Назив фасцикле",
"Go back" => "Иди назад",
"Folder exists already!" => "Фасцикла већ постоји!",
"New Folder" => "Нова фасцикла",
"Create" => "Направи",
"Explore" => "Истражи",
"Deleted feed" => "Обрисани доводи",
"Undo delete feed" => "Поништи брисање довода",
"Rename" => "Преименуј",
"Menu" => "Мени",
"No feed ordering" => "Без ређања довода",
"Reversed feed ordering" => "Обрнуто ређање довода",
"Normal feed ordering" => "Нормално ређање довода",
"Rename feed" => "Преименуј довод",
"Delete feed" => "Обриши довод",
"Mark all articles read" => "Означи све као прочитано",
"Dismiss" => "Откажи",
"Collapse" => "Скупи",
"Deleted folder" => "Обрисана фасцикла",
"Undo delete folder" => "Поништи брисање фасцикле",
"Rename folder" => "Преименуј фасциклу",
"Delete folder" => "Обриши фасциклу",
"Starred" => "Означено звездицом",
"Unread articles" => "Непрочитани чланци",
"All articles" => "Сви чланци",
"Settings" => "Поставке",
"Keyboard shortcuts" => "Пречице тастатуре",
"Disable mark read through scrolling" => "Искључи „означи прочитаним при клизању“",
"Compact view" => "Компактни приказ",
"Expand articles on key navigation" => "Рашири чланке при навигацији тастерима",
"Show all articles" => "Прикажи све чланке",
"Reverse ordering (oldest on top)" => "Обрнуто ређање (најстарији на врху)",
"Subscriptions (OPML)" => "Претплате (ОПМЛ)",
"Import" => "Увези",
"Export" => "Извези",
"Error when importing: file does not contain valid OPML" => "Грешка приликом увоза: фајл не садржи исправан ОПМЛ",
"Unread/Starred Articles" => "Непрочитани/Озвездани чланци",
"Error when importing: file does not contain valid JSON" => "Грешка приликом увоза: фајл не садржи исправан ЈСОН"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";

==> owncloud-news_7.0.1%2Bdfsg.orig.tar.gz: news-7.0.1/l10n/sr.php <==
<?php
$TRANSLATIONS = array(
"Feed contains invalid XML" => "Довод садржи неисправан ИксМЛ",
"Detected feed format is not supported" => "Откривени формат довода није подржан",
"SSL Certificate is invalid" => "ССЛ сертификат није исправан",
"Website not found" => "Веб сајт није пронађен",
"More redirects than allowed, aborting" => "Превише преусмеравања. Прекидам",
"Bigger than maximum allowed size" => "Веће него што је дозвољено",
"Request timed out" => "Време истека захтева",
"Request failed, network connection unavailable!" => "Неуспео захтев. Мрежа није доступна!",
"Request unauthorized. Are you logged in?" => "Неауторизован захтев. Јесте ли пријављени?",
"Request forbidden. Are you an admin?" => "Забрањен захтев. Ви сте администратор?",
"Token expired or app not enabled! Reload the page!" => "Дигитални кључ је истекао или апликација није омогућена! Учитајте поново страницу!",
"Internal server error! Please check your " => "Интерна грешка сервера! Молимо вас да проверите ваше",
"Request failed, ownCloud is in currently " => "Захтев није успео. оунКлауд је тренутно",
"Can not add feed: Exists already" => "Не могу да додам довод. Већ постоји",
"Articles without feed" => "Чланци без довода",
"Can not add folder: Exists already" => "Не могу да додам фасциклу. Већ постоји",
"Use ownCloud cron for updates" => "Користите оунКлаудов cron за ажурирања",
"Disable this if you run a custom updater such as the Python updater included in the app" => "Онемогућите ово ако користите прилагођени програма за ажурирање као што су Python-ов програм за ажурирање у оквиру апликације",
"Purge interval" => "Интервал чишћења",
"Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" => "Минимални број секунди пошто се обрисане емисије и фасцикле уклоне из базе; вредности испод 60 секунди се игноришу",
"Maximum read count per feed" => "Максимални број читања по емисији",
"Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" => "Дефинише максимални број чланака који се могу прочитати по eмисији који неће бити избрисани од стране диспечера; ако се стари чланци поново појављују након што их прочитате, повећајте ову вредност; негативне вредности попут -1 искључују ову функцију у потпуности.",
"Maximum redirects" => "Највише преусмеравања",
"How many redirects the feed fetcher should follow" => "Колико ће се преусмеравања следити",
"Maximum feed page size" => "Највећа страница довода",
"Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" => "Највећа величина довода у бајтовима. Ако је страница довода већа, ажурирање ће бити прекинуто.",
"Feed fetcher timeout" => "Време чекања довлачења",
"Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" => "Време у секундама које ће се чекати да се довод учита. Ако траје дуже, ажурирање ће се прекинути",
"Explore Service URL" => "Истражите сервисну адресу",
"If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" => "Ако је дато, ова сервисна адреса ће бити упитана за приказивање у секцији за истраживање емисије. За повратак за коришћење уграђеног сервис за истраживање, оставите ово празна",
"Saved" => "Сачувано",
"Download" => "Преузми",
"Close" => "Затвори",
"Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." => "Откривен је режим Ајакс или веб-крона! Ваши доводи неће бити ажурирани коректно. Препоручено је да користите системски крон или прилагођени програм за ажурирање.",
"How to set up the operating system cron" => "Како подестити крон оперативног система",
"How to set up a custom updater (faster and no possible deadlock) " => "Како подесити прилагођени систем за ажурирање (брже и без застоја)",
"Subscribe" => "Претплати ме",
"Refresh" => "Освежи",
"No articles available" => "Нема доступних чланака",
"No unread articles available" => "Нема непрочитаних чланака",
"Open website" => "Отвори веб сајт",
"Star article" => "Озвездај чланак",
"Unstar article" => "Скини звездицу",
"Keep article unread" => "Остави чланак непрочитаним",
"Remove keep article unread" => "Уклони да остане непрочитан",
"by" => "од",
"from" => "од",
"Play audio" => "Пустио аудио",
"Download video" => "Преузми видео",
"Download audio" => "Преузми аудио",
"Keyboard shortcut" => "Пречица тастатуре",
"Description" => "Опис",
"right" => "десно",
"Jump to next article" => "Пређи на следећи чланак",
"left" => "лево",
"Jump to previous article" => "Пређи на претходни чланак",
"Toggle star article" => "Мења озвезданост чланка",
"Star article and jump to next one" => "Озвездај чланак и иди на следећи",
"Toggle keep current article unread" => "Мења „остави тренутни чланак непрочитаним“",
"Open article in new tab" => "Отвори чланак у новом језичку",
"Toggle expand article in compact view" => "Мења „рашири чланак у компактном приказу“",
"Load next feed" => "Учитај следећи довод",
"Load previous feed" => "Учитај претходни довод",
"Load next folder" => "Учитај следећу фасциклу",
"Load previous folder" => "Учитај претходну фасциклу",
"Scroll to active navigation entry" => "Отклизај до активног уноса",
"Focus search field" => "Фокусирај на поље за претрагу",
"Mark current article's feed/folder read" => "Означи доводе/фасцикле тренутног чланка прочитаним",
"Web address" => "Веб адреса",
"Feed exists already!" => "Довод већ постоји!",
"Folder" => "фасцикла",
"No folder" => "Нема фасцикле",
"New folder" => "Нова фасцикла",
"Folder name" => "Назив фасцикле",
"Go back" => "Иди назад",
"Folder exists already!" => "Фасцикла већ постоји!",
"New Folder" => "Нова фасцикла",
"Create" => "Направи",
"Explore" => "Истражи",
"Deleted feed" => "Обрисани доводи",
"Undo delete feed" => "Поништи брисање довода",
"Rename" => "Преименуј",
"Menu" => "Мени",
"No feed ordering" => "Без ређања довода",
"Reversed feed ordering" => "Обрнуто ређање довода",
"Normal feed ordering" => "Нормално ређање довода",
"Rename feed" => "Преименуј довод",
"Delete feed" => "Обриши довод",
"Mark all articles read" => "Означи све као прочитано",
"Dismiss" => "Откажи",
"Collapse" => "Скупи",
"Deleted folder" => "Обрисана фасцикла",
"Undo delete folder" => "Поништи брисање фасцикле",
"Rename folder" => "Преименуј фасциклу",
"Delete folder" => "Обриши фасциклу",
"Starred" => "Означено звездицом",
"Unread articles" => "Непрочитани чланци",
"All articles" => "Сви чланци",
"Settings" => "Поставке",
"Keyboard shortcuts" => "Пречице тастатуре",
"Disable mark read through scrolling" => "Искључи „означи прочитаним при клизању“",
"Compact view" => "Компактни приказ",
"Expand articles on key navigation" => "Рашири чланке при навигацији тастерима",
"Show all articles" => "Прикажи све чланке",
"Reverse ordering (oldest on top)" => "Обрнуто ређање (најстарији на врху)",
"Subscriptions (OPML)" => "Претплате (ОПМЛ)",
"Import" => "Увези",
"Export" => "Извези",
"Error when importing: file does not contain valid OPML" => "Грешка приликом увоза: фајл не садржи исправан ОПМЛ",
"Unread/Starred Articles" => "Непрочитани/Озвездани чланци",
"Error when importing: file does not contain valid JSON" => "Грешка приликом увоза: фајл не садржи исправан ЈСОН"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
